---
title: '[릴리즈노트] 2024-05-20 업데이트'
category: 업데이트
tags:
  - 파트너정산
  - 업데이트
searchTags:
  - 파트너관리
  - 파트너정산
  - 릴리즈노트
datetime: 2024-05-19T15:00:00.000Z
---

<Callout title="2024년 5월 20일 파트너  정산 자동화 업데이트 소식을 안내드립니다." />



## 주요 업데이트 사항

✔️ 상세 내역 다운로드 API가 추가되었습니다.

- \[상세 내역 조회] 페이지에서 정산 상세 내역을 CSV 파일로 다운로드할 수 있습니다.
- 파일 다운로드 후 상세 내역을 확인하고 정산 명세서를 손쉽게 정리해보세요.



✔️ 예금주 조회 API 응답 본문이 변경되었습니다.

- 예금주 조회 API 요청 후 정상 인증 완료 시 응답 본문에 accountVerificationId가 추가되었습니다.

✔️ 파트너 관리 API 요청/응답 본문이 일부 변경되었습니다.

- 파트너 생성/다건 생성/수정 API 요청 시 파트너 유형이 비사업자 (원천징수납세자)인 경우, 생년월일을 선택적으로 등록할 수 있습니다.
  - 생년월일을 입력할 경우, 8자리로 입력 가능합니다. ex. (YYYYMMDD/YYYY-MM-DD)로 입력 가능
- 파트너 조회/다건 조회/생성/다건 생성/수정/보관/복원 API 응답 시 파트너 사업자 상태 필드(businessStatus)가 추가되었습니다. 사업자등록번호(businessRegistrationNumber)가 변경되거나 기입하여 생성한 경우에 사업자 상태가 업데이트 됩니다.
- 파트너 생성/수정 API 요청 시 예금주 계좌조회에 실패하더라도 파트너를 등록할 수 있습니다. 계좌조회가 어려운 경우 고객사가 직접 계좌 정보를 입력할 수 있습니다.
  - 예금주 조회에서 발급받은 accountVerificationId를 사용하여 추가적인 계좌 인증을 생략할 수 있습니다.

[\[파트너정산 자동화 릴리즈노트\] 2024-05-20 업데이트 보러가기↗](https://developers.portone.io/release-notes/platform/2024-05-20)
